==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitHubSourceSpecFluent<A extends GitHubSourceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAccessToken instead.
 * @return The buildable object.
 */
@Deprecated public SecretValueFromSource getAccessToken();
    public SecretValueFromSource buildAccessToken();
    public A withAccessToken(SecretValueFromSource accessToken);
    public Boolean hasAccessToken();
    public GitHubSourceSpecFluent.AccessTokenNested<A> withNewAccessToken();
    public GitHubSourceSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item);
    public GitHubSourceSpecFluent.AccessTokenNested<A> editAccessToken();
    public GitHubSourceSpecFluent.AccessTokenNested<A> editOrNewAccessToken();
    public GitHubSourceSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item);
    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides();
    public CloudEventOverrides buildCeOverrides();
    public A withCeOverrides(CloudEventOverrides ceOverrides);
    public Boolean hasCeOverrides();
    public GitHubSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
    public GitHubSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
    public GitHubSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
    public GitHubSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
    public GitHubSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
    public A addToEventTypes(int index,String item);
    public A setToEventTypes(int index,String item);
    public A addToEventTypes(String... items);
    public A addAllToEventTypes(Collection<String> items);
    public A removeFromEventTypes(String... items);
    public A removeAllFromEventTypes(Collection<String> items);
    public List<String> getEventTypes();
    public String getEventType(int index);
    public String getFirstEventType();
    public String getLastEventType();
    public String getMatchingEventType(Predicate<String> predicate);
    public Boolean hasMatchingEventType(Predicate<String> predicate);
    public A withEventTypes(List<String> eventTypes);
    public A withEventTypes(String... eventTypes);
    public Boolean hasEventTypes();
    public A addNewEventType(StringBuilder arg1);
    public A addNewEventType(int[] arg1,int arg2,int arg3);
    public A addNewEventType(char[] arg1);
    public A addNewEventType(StringBuffer arg1);
    public A addNewEventType(byte[] arg1,int arg2);
    public A addNewEventType(byte[] arg1);
    public A addNewEventType(char[] arg1,int arg2,int arg3);
    public A addNewEventType(byte[] arg1,int arg2,int arg3);
    public A addNewEventType(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewEventType(String arg1);
    public String getGithubAPIURL();
    public A withGithubAPIURL(String githubAPIURL);
    public Boolean hasGithubAPIURL();
    public A withNewGithubAPIURL(StringBuilder arg1);
    public A withNewGithubAPIURL(int[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(char[] arg1);
    public A withNewGithubAPIURL(StringBuffer arg1);
    public A withNewGithubAPIURL(byte[] arg1,int arg2);
    public A withNewGithubAPIURL(byte[] arg1);
    public A withNewGithubAPIURL(char[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(byte[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGithubAPIURL(String arg1);
    public String getOwnerAndRepository();
    public A withOwnerAndRepository(String ownerAndRepository);
    public Boolean hasOwnerAndRepository();
    public A withNewOwnerAndRepository(StringBuilder arg1);
    public A withNewOwnerAndRepository(int[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(char[] arg1);
    public A withNewOwnerAndRepository(StringBuffer arg1);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2);
    public A withNewOwnerAndRepository(byte[] arg1);
    public A withNewOwnerAndRepository(char[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOwnerAndRepository(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretToken instead.
 * @return The buildable object.
 */
@Deprecated public SecretValueFromSource getSecretToken();
    public SecretValueFromSource buildSecretToken();
    public A withSecretToken(SecretValueFromSource secretToken);
    public Boolean hasSecretToken();
    public GitHubSourceSpecFluent.SecretTokenNested<A> withNewSecretToken();
    public GitHubSourceSpecFluent.SecretTokenNested<A> withNewSecretTokenLike(SecretValueFromSource item);
    public GitHubSourceSpecFluent.SecretTokenNested<A> editSecretToken();
    public GitHubSourceSpecFluent.SecretTokenNested<A> editOrNewSecretToken();
    public GitHubSourceSpecFluent.SecretTokenNested<A> editOrNewSecretTokenLike(SecretValueFromSource item);
    public Boolean getSecure();
    public A withSecure(Boolean secure);
    public Boolean hasSecure();
    public A withNewSecure(String arg1);
    public A withNewSecure(boolean arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public GitHubSourceSpecFluent.SinkNested<A> withNewSink();
    public GitHubSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public GitHubSourceSpecFluent.SinkNested<A> editSink();
    public GitHubSourceSpecFluent.SinkNested<A> editOrNewSink();
    public GitHubSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public interface AccessTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretValueFromSourceFluent<GitHubSourceSpecFluent.AccessTokenNested<N>> {

            public N and();
            public N endAccessToken();    }


    public interface CeOverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CloudEventOverridesFluent<GitHubSourceSpecFluent.CeOverridesNested<N>> {

            public N and();
            public N endCeOverrides();    }


    public interface SecretTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretValueFromSourceFluent<GitHubSourceSpecFluent.SecretTokenNested<N>> {

            public N and();
            public N endSecretToken();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<GitHubSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverrides;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesFluent;
import java.util.List;
import io.fabric8.knative.internal.pkg.apis.duck.v1.CloudEventOverridesBuilder;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface GitHubSourceSpecFluent<A extends GitHubSourceSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAccessToken instead.
 * @return The buildable object.
 */
@Deprecated public SecretValueFromSource getAccessToken();
    public SecretValueFromSource buildAccessToken();
    public A withAccessToken(SecretValueFromSource accessToken);
    public Boolean hasAccessToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<A> withNewAccessToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item);
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<A> editAccessToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<A> editOrNewAccessToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item);
    
/**
 * This method has been deprecated, please use method buildCeOverrides instead.
 * @return The buildable object.
 */
@Deprecated public CloudEventOverrides getCeOverrides();
    public CloudEventOverrides buildCeOverrides();
    public A withCeOverrides(CloudEventOverrides ceOverrides);
    public Boolean hasCeOverrides();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<A> withNewCeOverrides();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<A> withNewCeOverridesLike(CloudEventOverrides item);
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<A> editCeOverrides();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverrides();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<A> editOrNewCeOverridesLike(CloudEventOverrides item);
    public A addToEventTypes(int index,String item);
    public A setToEventTypes(int index,String item);
    public A addToEventTypes(String... items);
    public A addAllToEventTypes(Collection<String> items);
    public A removeFromEventTypes(String... items);
    public A removeAllFromEventTypes(Collection<String> items);
    public List<String> getEventTypes();
    public String getEventType(int index);
    public String getFirstEventType();
    public String getLastEventType();
    public String getMatchingEventType(Predicate<String> predicate);
    public Boolean hasMatchingEventType(Predicate<String> predicate);
    public A withEventTypes(List<String> eventTypes);
    public A withEventTypes(String... eventTypes);
    public Boolean hasEventTypes();
    public A addNewEventType(StringBuilder arg1);
    public A addNewEventType(int[] arg1,int arg2,int arg3);
    public A addNewEventType(char[] arg1);
    public A addNewEventType(StringBuffer arg1);
    public A addNewEventType(byte[] arg1,int arg2);
    public A addNewEventType(byte[] arg1);
    public A addNewEventType(char[] arg1,int arg2,int arg3);
    public A addNewEventType(byte[] arg1,int arg2,int arg3);
    public A addNewEventType(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewEventType(String arg1);
    public String getGithubAPIURL();
    public A withGithubAPIURL(String githubAPIURL);
    public Boolean hasGithubAPIURL();
    public A withNewGithubAPIURL(StringBuilder arg1);
    public A withNewGithubAPIURL(int[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(char[] arg1);
    public A withNewGithubAPIURL(StringBuffer arg1);
    public A withNewGithubAPIURL(byte[] arg1,int arg2);
    public A withNewGithubAPIURL(byte[] arg1);
    public A withNewGithubAPIURL(char[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(byte[] arg1,int arg2,int arg3);
    public A withNewGithubAPIURL(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewGithubAPIURL(String arg1);
    public String getOwnerAndRepository();
    public A withOwnerAndRepository(String ownerAndRepository);
    public Boolean hasOwnerAndRepository();
    public A withNewOwnerAndRepository(StringBuilder arg1);
    public A withNewOwnerAndRepository(int[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(char[] arg1);
    public A withNewOwnerAndRepository(StringBuffer arg1);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2);
    public A withNewOwnerAndRepository(byte[] arg1);
    public A withNewOwnerAndRepository(char[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2,int arg3);
    public A withNewOwnerAndRepository(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewOwnerAndRepository(String arg1);
    
/**
 * This method has been deprecated, please use method buildSecretToken instead.
 * @return The buildable object.
 */
@Deprecated public SecretValueFromSource getSecretToken();
    public SecretValueFromSource buildSecretToken();
    public A withSecretToken(SecretValueFromSource secretToken);
    public Boolean hasSecretToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<A> withNewSecretToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<A> withNewSecretTokenLike(SecretValueFromSource item);
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<A> editSecretToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<A> editOrNewSecretToken();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<A> editOrNewSecretTokenLike(SecretValueFromSource item);
    public Boolean getSecure();
    public A withSecure(Boolean secure);
    public Boolean hasSecure();
    public A withNewSecure(String arg1);
    public A withNewSecure(boolean arg1);
    public String getServiceAccountName();
    public A withServiceAccountName(String serviceAccountName);
    public Boolean hasServiceAccountName();
    public A withNewServiceAccountName(StringBuilder arg1);
    public A withNewServiceAccountName(int[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(char[] arg1);
    public A withNewServiceAccountName(StringBuffer arg1);
    public A withNewServiceAccountName(byte[] arg1,int arg2);
    public A withNewServiceAccountName(byte[] arg1);
    public A withNewServiceAccountName(char[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3);
    public A withNewServiceAccountName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewServiceAccountName(String arg1);
    
/**
 * This method has been deprecated, please use method buildSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getSink();
    public Destination buildSink();
    public A withSink(Destination sink);
    public Boolean hasSink();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<A> withNewSink();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item);
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<A> editSink();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<A> editOrNewSink();
    public io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item);
    public interface AccessTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretValueFromSourceFluent<io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.AccessTokenNested<N>> {

            public N and();
            public N endAccessToken();    }


    public interface CeOverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,CloudEventOverridesFluent<io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.CeOverridesNested<N>> {

            public N and();
            public N endCeOverrides();    }


    public interface SecretTokenNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretValueFromSourceFluent<io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SecretTokenNested<N>> {

            public N and();
            public N endSecretToken();    }


    public interface SinkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DestinationFluent<io.fabric8.knative.eventing.contrib.github.v1alpha1.GitHubSourceSpecFluent.SinkNested<N>> {

            public N and();
            public N endSink();    }


}
